package com.ruoyi.protocol.sansi;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.board.domain.BoardInfo;
import com.ruoyi.board.domain.PresetContent;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.protocol.enums.ProtocolDefault;
import com.ruoyi.protocol.sansi.enums.SanSiFontColor;
import com.ruoyi.protocol.sansi.enums.SanSiFontStyle;
import com.ruoyi.protocol.service.IProtocolService;
import org.apache.commons.io.FileUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import zhishuang.wang.sansi.fcms.devinfor.DeviceControl;
import zhishuang.wang.sansi.fcms.devinfor.DeviceVar;
import zhishuang.wang.sansi.playlist.AreaItem;
import zhishuang.wang.sansi.playlist.PageItem;
import zhishuang.wang.sansi.playlist.PlayItem;
import zhishuang.wang.sansi.playlist.entry.*;
import zhishuang.wang.sansi.playlist.fcms.PlayListFcms;
import zhishuang.wang.sansi.tools.ReturnData;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

@Service
public class SanSiProtocol implements IProtocolService {
    private static final Logger log = LoggerFactory.getLogger(SanSiProtocol.class);
    Integer deviceId = 0;

    private String createTextItem(List<PresetContent> presetContentList, BoardInfo boardInfo) {
        Animation animation = new Animation();
        animation.setInAnimation(0);
        animation.setInAnimationSpeed(200);
        List<PlayItem> playItemList = new ArrayList<>();

        int index = 1;
        presetContentList.forEach(i -> {
            TextBase textBase = new TextBase(0, i.getContent());
            textBase.setFontSize(i.getFontSize()+","+i.getFontSize());
            textBase.setFontName(SanSiFontStyle.getStyleValueByName(i.getFontStyle()));
            textBase.setWordSpace(i.getLetterSpacing());
            BaseColour fontColour = SanSiFontColor.getBaseColourByColorName(i.getFontColor());
            if (null == fontColour) {
                log.error("BaseColour fontColour = SanSiFontColor.getBaseColourByColorName(presetContent.getFontColor()); 没有匹配到相应的字体颜色");
            }
            textBase.setFontColour(fontColour);
            PlayTimeBase textPlayTime = new PlayTimeBase(i.getPlayTime() * 10);
            PlayItem textPlayItem = new PlayItem(index, Integer.toString(index), "test" + index, textBase, textPlayTime);
            textPlayItem.setAnimation(animation);
            textPlayItem.setX(i.getFontPositionX());
            textPlayItem.setY(i.getFontPositionY());
            playItemList.add(textPlayItem);
        });

        String boardSize = boardInfo.getBoardSize();
        String[] split = StringUtils.split(boardSize, "*");
        if (split.length < 2) {
            log.info("尺寸有问题，请重新设置尺寸");
            return null;
        }
        int height = Integer.parseInt(split[0]);
        int width = Integer.parseInt(split[1]);

        AreaPositon areaPositon = new AreaPositon(0, 0, height, width, 0);
        AreaItem areaItem = new AreaItem("1", "areaItem", areaPositon, playItemList);

        List<AreaItem> areaItemList = new ArrayList<>();
        areaItemList.add(areaItem);

        PageItem pageItem = new PageItem("1", "pageItem", areaItemList);
        PlayListFcms plf = new PlayListFcms();

        String path = "./protocolFile/SanSi/" + DateUtils.dateTimeNow();
        String file = path + "/play.lst";
        try {
            FileUtils.forceMkdir(new File(path));
        } catch (IOException e) {
            log.error("创建文件夹失败");
            return null;
        }
        ReturnData rd = plf.createFcmsPlayList(file, pageItem);
        if (rd.getCode() != 0) {
            log.error("生成三思的上传文件出错了");
            return null;
        }
        return file;
    }

    @Override
    public boolean protocolSupport(String protocolName) {
        return StringUtils.equals(ProtocolDefault.SanSi.getName(), protocolName);
    }

    @Override
    public void loginDevice(BoardInfo boardInfo) {
        if (deviceId > 10) {
            deviceId = 0;
        }
        deviceId++;
        if (boardInfo.getBoardPort()<1) {
            boardInfo.setBoardPort(ProtocolDefault.SanSi.getPort());
        }
        DeviceVar.deviceInforInit(Integer.toString(deviceId), 1, boardInfo.getBoardIp(), boardInfo.getBoardPort(), 2048);
    }

    @Override
    public void logoutDevice() {
        DeviceVar.deviceInforDel(Integer.toString(deviceId));
    }

    @Override
    public void publishContent(BoardInfo boardInfo, List<PresetContent> presetContentList) {
        String path = createTextItem(presetContentList, boardInfo);
        uploadAndStartPlayList(path);
    }

    private void uploadAndStartPlayList(String path) {
        ReturnData uploadPlayListRD = DeviceControl.fcmsUploadPlayList(Integer.toString(deviceId), path);//上传播放表
        log.info("uploadPlayListRD:{}", JSON.toJSONString(uploadPlayListRD));
//        ReturnData activePlayListRD = DeviceControl.fcmsActivePlayList(Integer.toString(deviceId), "000");
//        if (activePlayListRD.getCode() != 0) {
//            log.error("播放错误");
//            return false;
//        }
//        return true;
    }
}
